OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Everyone" : "ทุกคน",
    "None" : "ไม่มี",
    "User" : "User",
    "Disabled" : "ปิดการใช้งาน",
    "Users" : "ผู้ใช้งาน",
    "Name" : "ชื่อ",
    "Saved" : "บันทึกแล้ว",
    "Copy link" : "คัดลอกลิงค์",
    "Favorite" : "รายการโปรด",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Loading" : "Loading",
    "Groups" : "กลุ่ม",
    "Error" : "ข้อผิดพลาด",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Back" : "ย้อนกลับ",
    "Close" : "ปิด",
    "Reply" : "ตอบกลับ",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "guest" : "ผู้เยี่ยมชม",
    "Settings" : "ตั้งค่า",
    "Edit" : "แก้ไข",
    "Dismiss" : "ยกเลิก",
    "Share link" : "แชร์ลิงค์",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "มุมมองแบบตาราง Grid",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "Android app" : "แอพฯ แอนดรอยด์",
    "iOS app" : "แอพฯ IOS",
    "Copy" : "คัดลอก",
    "Copied!" : "คัดลอกแล้ว",
    "Not supported!" : "ไม่สนับสนุน",
    "Press ⌘-C to copy." : "กด ⌘-C เพื่อคัดลอก",
    "Press Ctrl-C to copy." : "กด Ctrl-C เพื่อคัดลอก",
    "Cancel" : "ยกเลิก",
    "Change password" : "เปลี่ยนรหัสผ่าน",
    "Rename" : "เปลี่ยนชื่อ",
    "Send" : "ส่ง",
    "Share" : "แชร์",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Favorited" : "รายการโปรด"
},
"nplurals=1; plural=0;");
